@@ -404,7 +404,7 @@ def MakeProfiles(ClustersFileName="VicinityPermissiveClustsLinear" + "RM_A" + ".
             pool.join()
 
 
-    if __name__ == "LoupeTool.Loupe":
+    if __name__ == os.path.relpath(__file__).split('.')[0]:
         t1 = time.time()
         cnt = 0
 
